mercurial/sshpeer.py
changeset 37614 a81d02ea65db
parent 37498 aacfca6f9767
child 37717 0664be4f0c1f
--- a/mercurial/sshpeer.py	Wed Apr 11 10:51:38 2018 -0700
+++ b/mercurial/sshpeer.py	Wed Apr 11 12:49:08 2018 -0700
@@ -18,6 +18,7 @@
     wireproto,
     wireprotoserver,
     wireprototypes,
+    wireprotov1peer,
 )
 from .utils import (
     procutil,
@@ -352,7 +353,7 @@
 
     return protoname, caps
 
-class sshv1peer(wireproto.wirepeer):
+class sshv1peer(wireprotov1peer.wirepeer):
     def __init__(self, ui, url, proc, stdin, stdout, stderr, caps,
                  autoreadstderr=True):
         """Create a peer from an existing SSH connection.
@@ -589,7 +590,7 @@
 def instance(ui, path, create):
     """Create an SSH peer.
 
     The returned object conforms to the ``wireproto.wirepeer`` interface.
     """
     u = util.url(path, parsequery=False, parsefragment=False)
     if u.scheme != 'ssh' or not u.host or u.path is None:
@@ -589,7 +590,7 @@
     """Create an SSH peer.
 
-    The returned object conforms to the ``wireproto.wirepeer`` interface.
+    The returned object conforms to the ``wireprotov1peer.wirepeer`` interface.
     """
     u = util.url(path, parsequery=False, parsefragment=False)